The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

# Changelog

## 1.3.2 (2025-07-21)


### Fixed

- Fix memory leak in persistent executor [#6](https://github.com/keslerm/saltext-mqtt-return/issues/6)

## 1.3.1 (2025-07-02)


### Fixed

- Removed options from handler call [#2](https://github.com/keslerm/saltext-mqtt-return/issues/2)

## v1.3 (2025-07-02)

No significant changes.


## v1.0.0 (2025-07-02)


### Fixed

- Move message processing off main thread to not block [#1](https://github.com/keslerm/saltext-mqtt-return/issues/1)

## 1.2 (2025-07-02)


### Fixed

- Move message processing off main thread to not block [#1](https://github.com/keslerm/saltext-mqtt-return/issues/1)
